@@ -70,7 +70,7 @@ def web_tiddler_url(environ, tiddler, container='bags', full=True,
     will need to be reviewed.
     """
     if '_canonical_uri' in tiddler.fields:
-        return tiddler.fields['_canonical_uri']
+        return tiddler.fields['_canonical_uri'].encode('utf-8')
 
     saved_host = environ.get('HTTP_HOST', '')
     try:
@@ -79,7 +79,7 @@ def web_tiddler_url(environ, tiddler, container='bags', full=True,
         else:
             space_name = Space.name_from_bag(tiddler.bag)
         space_name = space_name + '.'
-    except ValueError, exc:
+    except ValueError:
         space_name = ''
 
     host = environ['tiddlyweb.config']['server_host']['host']
