@@ -58,12 +58,9 @@ class Serialization(HTMLSerialization):
         """
         tiddlers_url = (self.environ.get('SCRIPT_NAME', '')
                 + self.environ.get('PATH_INFO', ''))
-        if tiddlers.is_search and 'tiddlyweb.query.original' in self.environ:
-            title = 'Search for %s' % self.environ['tiddlyweb.query.original']
-        else:
-            title = tiddlers.title
-        revisions = tiddlers.is_revisions
+
         routing_args = self.environ.get('wsgiorg.routing_args', ([], {}))[1]
+
         container_name = ''
         container_type = 'bags'
         container_url = ''
@@ -73,11 +70,11 @@ class Serialization(HTMLSerialization):
         if routing_args and not tiddlers.is_search:
             if 'recipe_name' in routing_args:
                 name = get_route_value(self.environ, 'recipe_name')
+                container_url = '/recipes/%s' % name
                 container_name = 'Recipe %s' % name
                 container_type = 'recipes'
                 try:
                     store.get(Recipe(name)).policy.allows(user, 'read')
-                    container_url = '/recipes/%s' % name
                     container_policy = True
                 except PermissionsError:
                     pass
@@ -91,7 +88,7 @@ class Serialization(HTMLSerialization):
                 except PermissionsError:
                     pass
 
-            if revisions:
+            if tiddlers.is_revisions:
                 container_policy = True
 
         try:
@@ -110,16 +107,19 @@ class Serialization(HTMLSerialization):
 
         if tiddlers.is_search:
             template = 'search.html'
+            if 'tiddlyweb.query.original' in self.environ:
+                tiddlers.title = ('Search for %s'
+                        % self.environ['tiddlyweb.query.original'])
         else:
             template = 'tiddlers.html'
 
         return send_template(self.environ, template, {
             'meta_keywords': 'tiddlers, tiddlyspace',
             'meta_description': 'A list of tiddlers on TiddlySpace',
-            'title': title,
+            'title': tiddlers.title,
             'tiddler_url': tiddler_url,
             'environ': self.environ,
-            'revisions': revisions,
+            'revisions': tiddlers.is_revisions,
             'tiddlers_url': tiddlers_url.decode('utf-8', 'replace'),
             'space_uri': space_uri,
             'space_bag': space_bag,
